# Microsoft Azure SDK for Python

This package is no longer being maintained. Please install the [azure-ai-textanalytics](https://pypi.org/project/azure-ai-textanalytics/) package for the latest features and support.
